@@ -93,12 +93,7 @@ occuMulti <- function(detformulas, stateformulas,  data, maxOrder, starts,
 
   if(missing(starts)) starts <- rep(0, nP)
   fm <- optim(starts, nll, method = method, hessian = se, ...)
-
-  if(se) {
-    tryCatch(covMat <- solve(fm$hessian),
-      error=function(x) stop(simpleError("Hessian is singular.
-        Try providing starting values or using fewer covariates.")))
-  } else { covMat <- matrix(NA, nP, nP) }
+  covMat <- invertHessian(fm, nP, se)
 
   fmAIC <- 2 * fm$value + 2 * nP
   #----------------------------------------------------------------------------
