@@ -85,13 +85,7 @@ occuRN <- function(formula, data, K = 25, starts, method = "BFGS",
 
 	if(missing(starts)) starts <- rep(0, nP)
   fm <- optim(starts, nll, method = method, hessian = se, ...)
-	opt <- fm
-	if(se) {
-            tryCatch(covMat <- solve(fm$hessian),
-                     error=function(x) stop(simpleError("Hessian is singular.  Try providing starting values or using fewer covariates.")))
-	} else {
-            covMat <- matrix(NA, nP, nP)
-	}
+  covMat <- invertHessian(fm, nP, se)
   ests <- fm$par
   fmAIC <- 2 * fm$value + 2 * nP # + 2 * nP * (nP + 1) / (M - nP - 1)
   names(ests) <- c(occParms, detParms)
@@ -113,7 +107,7 @@ occuRN <- function(formula, data, K = 25, starts, method = "BFGS",
   umfit <- new("unmarkedFitOccuRN", fitType = "occuRN",
       call = match.call(), formula = formula, data = data,
       sitesRemoved = designMats$removed.sites, estimates = estimateList,
-      AIC = fmAIC, opt = opt, negLogLike = fm$value, nllFun = nll)
+      AIC = fmAIC, opt = fm, negLogLike = fm$value, nllFun = nll)
 
   return(umfit)
 }
