@@ -102,16 +102,10 @@ function (formula, data, K, mixture = c("P", "NB", "ZIP"), starts,
     if (missing(starts))
         starts <- rep(0, nP)
     fm <- optim(starts, nll, method = method, hessian = se, ...)
-    opt <- fm
     ests <- fm$par
     nbParm <- switch(mixture, NB = "alpha", ZIP = "psi", P = character(0))
     names(ests) <- c(lamParms, detParms, nbParm)
-    if (se) {
-        tryCatch(covMat <- solve(fm$hessian), error = function(x) stop(simpleError("Hessian is singular.  Try using fewer covariates.")))
-    }
-    else {
-        covMat <- matrix(NA, nP, nP)
-    }
+    covMat <- invertHessian(fm, nP, se)
     fmAIC <- 2 * fm$value + 2 * nP
     stateName <- "Abundance"
     stateEstimates <- unmarkedEstimate(name = stateName, short.name = "lam",
@@ -135,7 +129,7 @@ function (formula, data, K, mixture = c("P", "NB", "ZIP"), starts,
     }
     umfit <- new("unmarkedFitPCount", fitType = "pcount", call = match.call(),
         formula = formula, data = data, sitesRemoved = designMats$removed.sites,
-        estimates = estimateList, AIC = fmAIC, opt = opt, negLogLike = fm$value,
+        estimates = estimateList, AIC = fmAIC, opt = fm, negLogLike = fm$value,
         nllFun = nll, K = K, mixture = mixture)
     return(umfit)
 }
