@@ -8,10 +8,11 @@ options(continue=" ")
 
 
 ###################################################
-### code chunk number 2: distsamp.Rnw:106-114
+### code chunk number 2: distsamp.Rnw:106-115
 ###################################################
 library(unmarked)
-dists <- read.csv(system.file("csv", "distdata.csv", package="unmarked"))
+dists <- read.csv(system.file("csv", "distdata.csv", package="unmarked"),
+                  stringsAsFactors=TRUE)
 head(dists, 10)
 levels(dists$transect) <- c(levels(dists$transect), "g")
 levels(dists$transect)
@@ -21,14 +22,14 @@ yDat
 
 
 ###################################################
-### code chunk number 3: distsamp.Rnw:125-127
+### code chunk number 3: distsamp.Rnw:126-128
 ###################################################
 (covs <- data.frame(canopyHt = c(5, 8, 3, 2, 4, 7, 5),
 	habitat = c('A','A','A','A','B','B','B'), row.names=letters[1:7]))
 
 
 ###################################################
-### code chunk number 4: distsamp.Rnw:139-142
+### code chunk number 4: distsamp.Rnw:140-143
 ###################################################
 umf <- unmarkedFrameDS(y=as.matrix(yDat), siteCovs=covs, survey="line",
 	dist.breaks=c(0, 5, 10, 15, 20), tlength=rep(100, 7),
@@ -43,7 +44,7 @@ hist(umf, xlab="distance (m)", main="", cex.lab=0.8, cex.axis=0.8)
 
 
 ###################################################
-### code chunk number 6: distsamp.Rnw:188-193
+### code chunk number 6: distsamp.Rnw:189-194
 ###################################################
 hn_Null <- distsamp(~1~1, umf)
 hn_Null <- distsamp(~1~1, umf, keyfun="halfnorm", output="density",
@@ -53,13 +54,13 @@ hn_Hab.Ht <- distsamp(~canopyHt ~habitat, umf)
 
 
 ###################################################
-### code chunk number 7: distsamp.Rnw:208-209
+### code chunk number 7: distsamp.Rnw:209-210
 ###################################################
 haz_Null
 
 
 ###################################################
-### code chunk number 8: distsamp.Rnw:217-222
+### code chunk number 8: distsamp.Rnw:218-223
 ###################################################
 names(haz_Null)
 backTransform(haz_Null, type="state")
@@ -69,7 +70,7 @@ backTransform(linearComb(hn_Hab.Ht['det'], c(1, 5)))
 
 
 ###################################################
-### code chunk number 9: distsamp.Rnw:241-245
+### code chunk number 9: distsamp.Rnw:242-246
 ###################################################
 site.level.density <- predict(hn_Hab.Ht, type="state")$Predicted
 plotArea.inHectares <- 100 * 40 / 10000
@@ -78,7 +79,7 @@ site.level.abundance <- site.level.density * plotArea.inHectares
 
 
 ###################################################
-### code chunk number 10: distsamp.Rnw:253-261
+### code chunk number 10: distsamp.Rnw:254-262
 ###################################################
 getN.hat <- function(fit) {
     d <- predict(fit, type="state")$Predicted
@@ -91,7 +92,7 @@ pb
 
 
 ###################################################
-### code chunk number 11: distsamp.Rnw:284-288
+### code chunk number 11: distsamp.Rnw:285-289
 ###################################################
 head(habConstant <- data.frame(canopyHt = seq(2, 8, length=20),
 	habitat=factor("A", levels=c("A", "B"))))
@@ -100,7 +101,7 @@ head(habConstant <- data.frame(canopyHt = seq(2, 8, length=20),
 
 
 ###################################################
-### code chunk number 12: distsamp.Rnw:294-298
+### code chunk number 12: distsamp.Rnw:295-299
 ###################################################
 (Elambda <- predict(hn_Hab.Ht, type="state", newdata=htConstant,
 	appendData=TRUE))
