@@ -1,3 +1,58 @@
+test.umarkedMultFrame.crpifun <- function() {
+
+alfl <- read.csv(system.file("csv", "alfl.csv", package="unmarked"))
+alfl.covs <- read.csv(system.file("csv", "alflCovs.csv",package="unmarked"),
+ row.names=1)
+alfl$captureHistory <- paste(alfl$interval1, alfl$interval2, alfl$interval3,
+ sep="")
+alfl$captureHistory <- factor(alfl$captureHistory,
+     levels=c("001", "010", "011", "100", "101", "110", "111"))
+alfl$id <- factor(alfl$id, levels=rownames(alfl.covs))
+
+alfl.v1 <- alfl[alfl$survey==1,]
+alfl.H1 <- table(alfl.v1$id, alfl.v1$captureHistory)
+alfl.v2 <- alfl[alfl$survey==2,]
+alfl.H2 <- table(alfl.v2$id, alfl.v2$captureHistory)
+alfl.v3 <- alfl[alfl$survey==3,]
+alfl.H3 <- table(alfl.v3$id, alfl.v3$captureHistory)
+
+
+Y<- array(NA, c(50, 3, 7))
+Y[1:50,1,1:7]<- alfl.H1
+Y[1:50,2,1:7]<- alfl.H2
+Y[1:50,3,1:7]<- alfl.H3
+
+crPiFun <- function(p) {
+   p1 <- p[,1]
+   p2 <- p[,2]
+   p3 <- p[,3]
+   cbind("001" = (1 - p1) * (1 - p2) *      p3,
+         "010" = (1 - p1) *      p2  * (1 - p3),
+         "011" = (1 - p1) *      p2  *      p3,
+         "100" =      p1  * (1 - p2) * (1 - p3),
+         "101" =      p1  * (1 - p2) *      p3,
+         "110" =      p1  *      p2  * (1 - p3),
+         "111" =      p1  *      p2  *      p3)
+}
+
+intervalMat <- matrix(c('1','2','3'), 50, 3, byrow=TRUE)
+class(alfl.H1) <- "matrix"
+o2y <- matrix(1, 3, 7)
+
+
+ywide<- as.matrix( cbind(alfl.H1, alfl.H2)  )
+umf.cr1 <- unmarkedFrameGMM(y=ywide,
+  obsCovs=NULL, yearlySiteCovs=NULL,
+    obsToY=o2y, numPrimary=2, piFun="crPiFun")
+
+#(tmp <- gmultmix(~1, ~ 1, ~ 1, data=umf.cr1))
+#tmp@opt$par
+
+
+  checkEquals(dim(umf.cr1@obsToY)[1] , 6)
+  checkEquals(dim(umf.cr1@obsToY)[2] , 14)
+}
+
 
 
 test.umarkedMultFrame.subset <- function() {
